# ListProperties

The properties of a list that describe the look and feel of bullets belonging to paragraphs associated with a list.

**Type:** object

## Properties

- **nestingLevels** (array of [NestingLevel](nestinglevel.md)): Describes the properties of the bullets at the associated level. A list has at most 9 levels of nesting with nesting level 0 corresponding to the top-most level and nesting level 8 corresponding to the most nested level. The nesting levels are returned in ascending order with the least nested returned first.
